@@ -12,7 +12,7 @@ LOG = minimal_logger(__name__)
 
 try:                                        # pragma: no cover
     NullHandler = logging.NullHandler       # pragma: no cover
-except AttributeError as e:                 # pragma: no cover
+except AttributeError:                      # pragma: no cover
     # Not supported on Python < 3.1/2.7     # pragma: no cover
     class NullHandler(logging.Handler):     # pragma: no cover
 
